<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>Over Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>Vertalers</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>Met dank aan</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>Licentie-overeenkomst</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Op Qt gebaseerde multimediaspeler (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="72"/>
        <source>Version: %1</source>
        <translation>Versie: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>(c) %1-%2 Qmmp-ontwikkelaarsteam</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Transports:</source>
        <translation>Protocollen:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="90"/>
        <source>Decoders:</source>
        <translation>Decoders:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="98"/>
        <source>Engines:</source>
        <translation>Aandrijvingen:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="105"/>
        <source>Effects:</source>
        <translation>Effecten:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="134"/>
        <source>File dialogs:</source>
        <translation>Bestandsvensters:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="143"/>
        <source>User interfaces:</source>
        <translation>Vormgevingen:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="126"/>
        <source>Output plugins:</source>
        <translation>Uitvoerplug-ins:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="73"/>
        <source>Qt version: %1 (compiled with %2)</source>
        <translation>Qt-versie: %1 (gecompileerd met %2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="74"/>
        <source>Qt platform: %1</source>
        <translation>Qt-platform: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="75"/>
        <source>System: %1</source>
        <translation>Systeem: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Build ABI: %1</source>
        <translation>Bouw-abi: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="113"/>
        <source>Visual plugins:</source>
        <translation>Visuele plug-ins:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="120"/>
        <source>General plugins:</source>
        <translation>Algemene plug-ins:</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>Voer een url in</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="45"/>
        <source>&amp;Add</source>
        <translation>&amp;Toevoegen</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="95"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="46"/>
        <source>Select Color</source>
        <translation>Kleur kiezen</translation>
    </message>
</context>
<context>
    <name>ColumnEditor</name>
    <message>
        <location filename="../forms/columneditor.ui" line="14"/>
        <source>Edit Column</source>
        <translation>Kolom aanpassen</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="36"/>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="76"/>
        <source>Format:</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="64"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="29"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="86"/>
        <source>Artist</source>
        <translation>Artiest</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="87"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="91"/>
        <source>Title</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="94"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="95"/>
        <source>Comment</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="96"/>
        <source>Composer</source>
        <translation>Componist</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="97"/>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="102"/>
        <source>Year</source>
        <translation>Jaar</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="101"/>
        <source>Track Index</source>
        <translation>Nummerindex</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="88"/>
        <source>Artist - Album</source>
        <translation>Artiest - Album</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="89"/>
        <source>Artist - Title</source>
        <translation>Artiest - Titel</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="90"/>
        <source>Album Artist</source>
        <translation>Albumartiest</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="92"/>
        <source>Track Number</source>
        <translation>Volgnummer</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="93"/>
        <source>Two-digit Track Number</source>
        <translation>Tweecijferig volgnummer</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="98"/>
        <source>Disc Number</source>
        <translation>Schijfnummer</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="99"/>
        <source>File Name</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="100"/>
        <source>File Path</source>
        <translation>Bestandspad</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="103"/>
        <source>Parent Directory Name</source>
        <translation>Naam van bovenliggende map</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="104"/>
        <source>Parent Directory Path</source>
        <translation>Pad naar bovenliggende map</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="105"/>
        <source>Custom</source>
        <translation>Aangepast</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Qmmp-instellingen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>Plug-ins</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>Verbindingen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="1016"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="153"/>
        <source>Metadata</source>
        <translation>Metagegevens</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="183"/>
        <source>Convert %20 to blanks</source>
        <translation>%20 omzetten in spaties</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="159"/>
        <source>Load metadata from files</source>
        <translation>Metagegevens uit bestanden laden</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="176"/>
        <source>Convert underscores to blanks</source>
        <translation>Onderliggende streepjes omzetten in spaties</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="226"/>
        <source>Group format:</source>
        <translation>Groepsopmaak:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="242"/>
        <location filename="../forms/configdialog.ui" line="267"/>
        <location filename="../forms/configdialog.ui" line="730"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="169"/>
        <source>Read tags while loading a playlist</source>
        <translation>Tags uitlezen tijdens laden van afspeellijst</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="193"/>
        <source>Group Mode</source>
        <translation>Groeperingsmodus</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="202"/>
        <source>Group size:</source>
        <translation>Groepsgrootte:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="219"/>
        <source>Show dividing line</source>
        <translation>Scheidingslijn tonen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="251"/>
        <source>Extra row format:</source>
        <translation>Aanvullende rij-opmaak:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="276"/>
        <source>Show extra row</source>
        <translation>Aanvullende rij tonen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="283"/>
        <source>Show cover</source>
        <translation>Hoes tonen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="293"/>
        <source>Directory Scanning Options</source>
        <translation>Opties voor het doorzoeken van mappen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="299"/>
        <source>Restrict files to:</source>
        <translation>Gebruikte bestandsformaten:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="306"/>
        <location filename="../forms/configdialog.ui" line="323"/>
        <location filename="../forms/configdialog.ui" line="591"/>
        <location filename="../forms/configdialog.ui" line="605"/>
        <source>A list of file masks separated by comma.</source>
        <translation>Een kommagescheiden bestandsmaskerlijst.</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="316"/>
        <location filename="../forms/configdialog.ui" line="598"/>
        <source>Exclude files:</source>
        <translation>Uitgesloten bestanden:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="336"/>
        <source>Miscellaneous</source>
        <translation>Overig</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="342"/>
        <source>Auto-save playlist when modified</source>
        <translation>Afspeellijst automatisch opslaan na aanpassingen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="349"/>
        <source>Clear previous playlist when opening new one</source>
        <translation>Vorige afspeellijst verwijderen na het openen van een nieuwe</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="402"/>
        <location filename="../configdialog.cpp" line="339"/>
        <source>Preferences</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="419"/>
        <location filename="../configdialog.cpp" line="342"/>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="465"/>
        <source>Description</source>
        <translation>Omschrijving</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="470"/>
        <source>Filename</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="482"/>
        <source>Look and Feel</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="488"/>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="521"/>
        <source>Display average bitrate</source>
        <translation>Gemiddelde bitsnelheid tonen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="531"/>
        <source>Playback</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="537"/>
        <source>Continue playback on startup</source>
        <translation>Afspelen voortzetten bij opstarten</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="544"/>
        <source>Determine file type by content</source>
        <translation>Bestandstype bepalen op basis van inhoud</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="551"/>
        <source>Add files from command line to this playlist:</source>
        <translation>Voeg bestanden van de opdrachtprompt toe aan de afspeellijst:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="568"/>
        <source>Cover Image Retrieve</source>
        <translation>Hoes ophalen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="574"/>
        <source>Use separate image files</source>
        <translation>Aparte afbeeldingsbestanden gebruiken</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="584"/>
        <source>Include files:</source>
        <translation>Inclusief de bestanden:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="614"/>
        <source>Recursive search depth:</source>
        <translation>Recursieve zoekdiepte:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="652"/>
        <source>URL Dialog</source>
        <translation>URL-venster</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="658"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>URL automatisch plakken van klembord</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="668"/>
        <source>CUE Editor</source>
        <translation>CUE-bewerker</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="674"/>
        <source>Use system font</source>
        <translation>Systeemlettertype gebruiken</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="695"/>
        <source>Font:</source>
        <translation>Lettertype:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="720"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="759"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="771"/>
        <source>Enable proxy usage</source>
        <translation>Proxy gebruiken</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="778"/>
        <source>Proxy type:</source>
        <translation>Soort proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="788"/>
        <source>Proxy host name:</source>
        <translation>Proxy-hostnaam:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="805"/>
        <source>Proxy port:</source>
        <translation>Proxypoort:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="822"/>
        <source>Use authentication with proxy</source>
        <translation>Proxy-authenticatie gebruiken</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="829"/>
        <source>Proxy user name:</source>
        <translation>Proxy-gebruikersnaam:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="846"/>
        <source>Proxy password:</source>
        <translation>Proxy-wachtwoord:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="886"/>
        <source>Replay Gain</source>
        <translation>Replay Gain</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="892"/>
        <source>Replay Gain mode:</source>
        <translation>Replay Gain-modus:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="909"/>
        <source>Preamp:</source>
        <translation>Voorversterking:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="941"/>
        <location filename="../forms/configdialog.ui" line="986"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="954"/>
        <source>Default gain:</source>
        <translation>Standaard verhoging:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1006"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Piekinformatie gebruiken om haperingen te voorkomen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1022"/>
        <source>Buffer size:</source>
        <translation>Buffergrootte:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1048"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1081"/>
        <source>Use software volume control</source>
        <translation>Softwarematige volumeregeling gebruiken</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1121"/>
        <source>Use two passes for equalizer</source>
        <translation>Equalizer twee keer passeren</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1064"/>
        <source>Volume adjustment step:</source>
        <translation>Volumestap:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="356"/>
        <source>Skip already existing tracks when adding</source>
        <translation>Reeds aanwezige nummers overslaan tijdens toevoegen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="363"/>
        <source>Stop playback after removing of current track</source>
        <translation>Afspelen van huidig nummer stoppen na verwijderen</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1088"/>
        <source>Output bit depth:</source>
        <translation>Bitdiepte van uitvoer:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1029"/>
        <source>Use dithering</source>
        <translation>Ruis gebruiken</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="63"/>
        <source>1 row</source>
        <translation>1 rij</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="64"/>
        <source>3 rows</source>
        <translation>3 rijen</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="65"/>
        <source>4 rows</source>
        <translation>4 rijen</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="66"/>
        <source>5 rows</source>
        <translation>5 rijen</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Track</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="69"/>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="202"/>
        <source>Transports</source>
        <translation>Protocollen</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="213"/>
        <source>Decoders</source>
        <translation>Decoders</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="224"/>
        <source>Engines</source>
        <translation>Aandrijvingen</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="236"/>
        <source>Effects</source>
        <translation>Effecten</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="247"/>
        <source>Visualization</source>
        <translation>Visualisatie</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="259"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="270"/>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="281"/>
        <source>File Dialogs</source>
        <translation>Bestandsvensters</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="293"/>
        <source>User Interfaces</source>
        <translation>Vormgevingen</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="352"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;Autodetect&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="353"/>
        <source>Brazilian Portuguese</source>
        <translation>Portugees (Brazilië)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="354"/>
        <source>Chinese Simplified</source>
        <translation>Chinees (Vereenvoudigd)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="355"/>
        <source>Chinese Traditional</source>
        <translation>Chinees (Traditioneel)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="356"/>
        <source>Czech</source>
        <translation>Tsjechisch</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="357"/>
        <source>Dutch</source>
        <translation>Nederlands</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="358"/>
        <source>English</source>
        <translation>Engels</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="359"/>
        <source>French</source>
        <translation>Frans</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="360"/>
        <source>Galician</source>
        <translation>Galicisch</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="361"/>
        <source>German</source>
        <translation>Duits</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="362"/>
        <source>Greek</source>
        <translation>Grieks</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="363"/>
        <source>Hebrew</source>
        <translation>Hebreeuws</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="364"/>
        <source>Hungarian</source>
        <translation>Hongaars</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="365"/>
        <source>Indonesian</source>
        <translation>Indonesisch</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Italian</source>
        <translation>Italiaans</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="367"/>
        <source>Japanese</source>
        <translation>Japans</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="368"/>
        <source>Kazakh</source>
        <translation>Kazachs</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="369"/>
        <source>Korean</source>
        <translation>Koreaans</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="370"/>
        <source>Lithuanian</source>
        <translation>Litouws</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="371"/>
        <source>Polish</source>
        <translation>Pools</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Portuguese</source>
        <translation>Portugees</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="373"/>
        <source>Russian</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="374"/>
        <source>Serbian</source>
        <translation>Servisch</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="375"/>
        <source>Slovak</source>
        <translation>Slowaaks</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="376"/>
        <source>Swedish</source>
        <translation>Zweeds</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="377"/>
        <source>Spanish</source>
        <translation>Spaans</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="378"/>
        <source>Turkish</source>
        <translation>Turks</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="379"/>
        <source>Ukrainian</source>
        <translation>Oekraïens</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="380"/>
        <source>Serbian (Ijekavian)</source>
        <translation>Servisch (Ijekavisch)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="381"/>
        <source>Serbian (Ekavian)</source>
        <translation>Servisch (Ekavisch)</translation>
    </message>
</context>
<context>
    <name>CoverEditor</name>
    <message>
        <location filename="../forms/covereditor.ui" line="22"/>
        <source>Image source:</source>
        <translation>Afbeeldingsbron:</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="76"/>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="83"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="90"/>
        <source>Save as...</source>
        <translation>Opslaan als...</translation>
    </message>
    <message>
        <location filename="../covereditor.cpp" line="34"/>
        <source>External File</source>
        <translation>Extern bestand</translation>
    </message>
    <message>
        <location filename="../covereditor.cpp" line="35"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>CoverViewer</name>
    <message>
        <location filename="../coverviewer.cpp" line="35"/>
        <source>&amp;Save As...</source>
        <translation>Op&amp;slaan als...</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="68"/>
        <source>Save Cover As</source>
        <translation>Hoes opslaan als</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="70"/>
        <location filename="../coverviewer.cpp" line="83"/>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="81"/>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
</context>
<context>
    <name>CueEditor</name>
    <message>
        <location filename="../forms/cueeditor.ui" line="40"/>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <location filename="../forms/cueeditor.ui" line="47"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../forms/cueeditor.ui" line="54"/>
        <source>Save as...</source>
        <translation>Opslaan als...</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="131"/>
        <source>Open CUE File</source>
        <translation>CUE-bestand openen</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="131"/>
        <location filename="../cueeditor.cpp" line="152"/>
        <source>CUE Files</source>
        <translation>CUE-bestanden</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="150"/>
        <source>Save CUE File</source>
        <translation>CUE-bestand opslaan</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="44"/>
        <source>Open the directory containing this file</source>
        <translation>Open de bijbehorende map van dit bestand</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="63"/>
        <source>Summary</source>
        <translation>Samenvatting</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="207"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="260"/>
        <source>Cover</source>
        <translation>Hoes</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="286"/>
        <source>Lyrics</source>
        <translation>Songteksten</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="306"/>
        <source>Title</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="307"/>
        <source>Artist</source>
        <translation>Artiest</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="308"/>
        <source>Album artist</source>
        <translation>Albumartiest</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="309"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="310"/>
        <source>Comment</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="311"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="312"/>
        <source>Composer</source>
        <translation>Componist</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="313"/>
        <source>Year</source>
        <translation>Jaar</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="314"/>
        <source>Track</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="315"/>
        <source>Disc number</source>
        <translation>Schijfnummer</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="334"/>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="337"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="337"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="338"/>
        <source>Sample rate</source>
        <translation>Samplesnelheid</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="338"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="339"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="340"/>
        <source>Sample size</source>
        <translation>Samplegrootte</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="340"/>
        <source>bits</source>
        <translation>bits</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="341"/>
        <source>Format name</source>
        <translation>Opmaak</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="342"/>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="342"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="386"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="386"/>
        <source>No</source>
        <translation>Nee</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Ga naar nummer</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="46"/>
        <source>Filter</source>
        <translation>Filteren</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="85"/>
        <location filename="../jumptotrackdialog.cpp" line="120"/>
        <location filename="../jumptotrackdialog.cpp" line="151"/>
        <source>Queue</source>
        <translation>Wachtrij</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="105"/>
        <source>Jump To</source>
        <translation>Ga naar</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="95"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="96"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="118"/>
        <location filename="../jumptotrackdialog.cpp" line="149"/>
        <source>Unqueue</source>
        <translation>Verwijderen uit wachtrij</translation>
    </message>
</context>
<context>
    <name>MetaDataFormatterMenu</name>
    <message>
        <location filename="../metadataformattermenu.cpp" line="27"/>
        <source>Artist</source>
        <translation>Artiest</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="28"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="29"/>
        <source>Album Artist</source>
        <translation>Albumartiest</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="32"/>
        <source>Title</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="33"/>
        <source>Track Number</source>
        <translation>Volgnummer</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="34"/>
        <source>Two-digit Track Number</source>
        <translation>Tweecijferig volgnummer</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="38"/>
        <source>Track Index</source>
        <translation>Nummerindex</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="40"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="41"/>
        <source>Comment</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="42"/>
        <source>Composer</source>
        <translation>Componist</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="45"/>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="55"/>
        <source>Artist - Album</source>
        <translation>Artiest - Album</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="61"/>
        <source>Duration | Format | Bitrate</source>
        <translation>Duur | Formaat | Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="64"/>
        <source>Year | Duration | Bitrate</source>
        <translation>Jaar | Duur | Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="65"/>
        <source>Year | Duration | Sample rate</source>
        <translation>Jaar | Duur | Samplesnelheid</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="65"/>
        <source>%y | %if(%l,%l | ,)%{samplerate} Hz</source>
        <translation>%y | %if(%l,%l | ,)%{samplerate} Hz</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="69"/>
        <source>Parent Directory Path</source>
        <translation>Pad naar bovenliggende map</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="71"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="72"/>
        <source>Sample Rate</source>
        <translation>Samplesnelheid</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="73"/>
        <source>Number of Channels</source>
        <translation>Aantal kanalen</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="74"/>
        <source>Sample Size</source>
        <translation>Samplegrootte</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="75"/>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="76"/>
        <source>Decoder</source>
        <translation>Decoder</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="79"/>
        <source>File Size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="43"/>
        <source>Disc Number</source>
        <translation>Schijfnummer</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="48"/>
        <source>File Name</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="49"/>
        <source>File Path</source>
        <translation>Bestandspad</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="44"/>
        <source>Year</source>
        <translation>Jaar</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="51"/>
        <location filename="../metadataformattermenu.cpp" line="57"/>
        <location filename="../metadataformattermenu.cpp" line="66"/>
        <source>Condition</source>
        <translation>Staat</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="50"/>
        <source>Artist - Title</source>
        <translation>Artiest - Naam</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="56"/>
        <source>Artist - [Year] Album</source>
        <translation>Artiest - [Jaar] Album</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="61"/>
        <source>%if(%l,%l | ,)%{format} | %{bitrate} kbps</source>
        <translation>%if(%l,%l | ,)%{format} | %{bitrate} kbps</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="62"/>
        <source>%if(%l,%l | ,)%{format} | %{bitrate} kbps | %{samplerate} Hz</source>
        <translation>%if(%l,%l | ,)%{format} | %{bitrate} kbps | %{samplerate} Hz</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="62"/>
        <source>Duration | Format | Bitrate | Sample rate</source>
        <translation>Duur | Formaat | Bitsnelheid | Samplesnelheid</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="63"/>
        <source>Duration | Format | Sample rate</source>
        <translation>Duur | Formaat | Samplesnelheid</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="63"/>
        <source>%if(%l,%l | ,)%{format} | %{samplerate} Hz</source>
        <translation>%if(%l,%l | ,)%{format} | %{samplerate} Hz</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="64"/>
        <source>%y | %if(%l,%l | ,)%{bitrate} kbps</source>
        <translation>%y | %if(%l,%l | ,)%{bitrate} kbps</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="68"/>
        <source>Parent Directory Name</source>
        <translation>Naam van bovenliggende map</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="123"/>
        <source>Unsupported playlist format</source>
        <translation>Niet-ondersteund afspeellijstformaat</translation>
    </message>
</context>
<context>
    <name>PlayListGroup</name>
    <message>
        <location filename="../playlistgroup.cpp" line="145"/>
        <source>Streams</source>
        <translation>Streams</translation>
    </message>
    <message>
        <location filename="../playlistgroup.cpp" line="161"/>
        <source>Empty group</source>
        <translation>Lege groep</translation>
    </message>
</context>
<context>
    <name>PlayListHeaderModel</name>
    <message>
        <location filename="../playlistheadermodel.cpp" line="35"/>
        <source>Artist - Title</source>
        <translation>Artiest - Naam</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="185"/>
        <source>Title</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="186"/>
        <source>Add Column</source>
        <translation>Kolom toevoegen</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="177"/>
        <location filename="../playlistmanager.cpp" line="329"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="39"/>
        <source>%if(%l,%l | ,)%{format} | %{bitrate} kbps | %{samplerate} Hz</source>
        <translation>%if(%l,%l | ,)%{format} | %{bitrate} kbps | %{samplerate} Hz</translation>
    </message>
    <message>
        <location filename="../qmmpuisettings.cpp" line="64"/>
        <source>Playlist</source>
        <translation>Afspeellijst</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="35"/>
        <source>Qt File Dialog</source>
        <translation>Qt-bestandsvenster</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation>Sneltoets aanpassen</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Druk op de toetscombinatie die je wilt toewijzen</translation>
    </message>
    <message>
        <location filename="../shortcutdialog.cpp" line="31"/>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Tags bewerken</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Artiest:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Album artist:</source>
        <translation>Albumartiest:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="123"/>
        <source>Composer:</source>
        <translation>Componist:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="143"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="169"/>
        <source>Track:</source>
        <translation>Nummer:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="190"/>
        <location filename="../forms/tageditor.ui" line="228"/>
        <location filename="../forms/tageditor.ui" line="260"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="203"/>
        <source>Year:</source>
        <translation>Jaar:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="250"/>
        <source>Disc number:</source>
        <translation>Schijfnummer:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="275"/>
        <source>Comment:</source>
        <translation>Opmerking:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="311"/>
        <source>Include selected tag in file</source>
        <translation>Geselecteerde tag toevoegen aan bestand</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Sjabloonbewerker</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="30"/>
        <source>Insert</source>
        <translation>Invoegen</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="136"/>
        <location filename="../uihelper.cpp" line="148"/>
        <source>All Supported Bitstreams</source>
        <translation>Alle ondersteunde bitstreams</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="142"/>
        <source>Select one or more files to open</source>
        <translation>Kies één of meer te openen bestanden</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="154"/>
        <source>Select one or more files to play</source>
        <translation>Kies één of meer af te spelen bestanden</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="162"/>
        <source>Choose a directory</source>
        <translation>Kies een map</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="178"/>
        <location filename="../uihelper.cpp" line="202"/>
        <source>Playlist Files</source>
        <translation>Afspeellijstbestanden</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="180"/>
        <source>Open Playlist</source>
        <translation>Afspeellijst openen</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="205"/>
        <location filename="../uihelper.cpp" line="224"/>
        <source>Save Playlist</source>
        <translation>Afspeellijst opslaan</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="224"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 bestaat al.
Wil je het overschrijven?</translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="26"/>
        <source>Visualization</source>
        <translation>Visualisatie</translation>
    </message>
</context>
<context>
    <name>WinFileAssocPage</name>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="43"/>
        <source>Media files handled by Qmmp:</source>
        <translation>Mediabestanden voor Qmmp:</translation>
    </message>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="17"/>
        <source>Select All</source>
        <translation>Alles selecteren</translation>
    </message>
</context>
</TS>
